@@ -1,8 +1,9 @@
 from webob import Request
 from webob.exc import HTTPError
+from webob.exc import HTTPException
 from webob.exc import HTTPNotFound
 from webob.exc import HTTPMovedPermanently
-from .publisher import Publisher
+from otto.publisher import Publisher
 
 class Application(Publisher):
     """WSGI-Application.
@@ -13,16 +14,22 @@ class Application(Publisher):
     """
 
     def __call__(self, environ, start_response):
+        """WSGI application callable."""
+
         response = self.publish(environ)
         return response(environ, start_response)
 
     def publish(self, environ):
+        """Return response for request given by ``environ``."""
+
         request = Request(environ)
         path = request.path_info
         controller = self.match(path)
         if controller is None:
-            # try adding or removing a trailing slash
-            path = path.rstrip('/') if path.endswith('/') else path + '/'
+            if path.endswith('/'):
+                path = path.rstrip('/')
+            else:
+                path = path + '/'
             controller = self.match(path)
             if controller is not None:
                 request.path_info = path
@@ -34,4 +41,6 @@ class Application(Publisher):
                 response = controller(request)
             except HTTPError, response:
                 pass
+            except HTTPException, e: # pragma no cover
+                response = e.wsgi_response
         return response
