@@ -7,18 +7,17 @@ from otto.utils import url_quote
 
 try:
     from collections import namedtuple
-    Match = namedtuple('Match', 'route path dict')
+    Match = namedtuple('Match', 'route dict')
 except ImportError: # pragma no cover
     class Match(tuple):
-        def __new__(cls, route, path, dict):
-            return tuple.__new__(cls, (route, path, dict))
+        def __new__(cls, route, dict):
+            return tuple.__new__(cls, (route, dict))
 
         def __repr__(self):
-            return '%s(route=%s, path=%s, dict=%s)' % (
-                type(self).__name__, self.route, self.path, self.dict)
+            return '%s(route=%s, dict=%s)' % (
+                type(self).__name__, self.route, self.dict)
 
         route = property(operator.itemgetter(0))
-        path = property(operator.itemgetter(1))
         dict = property(operator.itemgetter(2))
 
 re_segment = re.compile(r':([a-z]+)')
@@ -32,11 +31,11 @@ def matcher(path):
 
     >>> matchdict = matcher('/a/:b/*/:d/e')('/a/b/c/d/e')
     >>> sorted(matchdict.items())
-    [('*', (u'c',)), ('b', u'b'), ('d', u'd')]
+    [('', (u'c',)), ('b', u'b'), ('d', u'd')]
 
     >>> matchdict = matcher('/a/:b/*/:e')('/a/b/c/d/e')
     >>> sorted(matchdict.items())
-    [('*', (u'c', u'd')), ('b', u'b'), ('e', u'e')]
+    [('', (u'c', u'd')), ('b', u'b'), ('e', u'e')]
 
     >>> matcher('/')('/')
     {}
@@ -48,14 +47,14 @@ def matcher(path):
     {'foo': u''}
 
     >>> matcher('/*')('/')
-    {'*': ()}
+    {'': ()}
 
     >>> matcher('/docs/*')('/docs/math/pi')
-    {'*': (u'math', u'pi')}
+    {'': (u'math', u'pi')}
 
     >>> matchdict = matcher('/docs/*/:name')(u'/docs/math/pi')
     >>> sorted(matchdict.items())
-    [('*', (u'math',)), ('name', u'pi')]
+    [('', (u'math',)), ('name', u'pi')]
 
     >>> matcher('/*path')('/some/path')
     {'path': (u'some', u'path')}
@@ -69,11 +68,11 @@ def matcher(path):
     >>> matcher('/s/(?=[abc]+):term')('/s/abc')['term']
     u'abc'
 
-    >>> matcher(r'/(?=.\*\.txt)*')('/test.txt')
-    {'*': (u'test.txt',)}
+    >>> matcher(r'/(?=.+\.txt)*')('/test.txt')
+    {'': (u'test.txt',)}
 
-    >>> matcher('/(?=.+\.txt)*')('/test.txt')
-    {'*': (u'test.txt',)}
+    >>> matcher(r'/(?=.\*\.txt)*')('/test.txt')
+    {'': (u'test.txt',)}
 
     >>> matcher('/(?=.+\.txt)*')('/test.rst') is None
     True
@@ -85,7 +84,7 @@ def matcher(path):
     # setup star match
     star = re_stararg.search(path)
     if star is not None:
-        name = star.group('name') or '*'
+        name = star.group('name')
         path = re_stararg.sub('(?P<_star>.*?)', path)
 
     # substitute segments into capture groups
@@ -122,22 +121,22 @@ def generator(path):
     >>> generator('/:name/')({'name': 'foo'})
     '/foo/'
 
-    >>> generator('/*')({'*': ('some', 'path')})
+    >>> generator('/*')({'': ('some', 'path')})
     '/some/path'
 
-    >>> generator('/*/')({'*': ('some', 'path')})
+    >>> generator('/*/')({'': ('some', 'path')})
     '/some/path/'
 
-    >>> generator('/*')({'*': 'some/path'})
+    >>> generator('/*')({'': 'some/path'})
     '/some/path'
 
     >>> generator('/:foo*bar')({'foo': 'foo', 'bar': ('bar', 'boo')})
     '/foo/bar/boo'
 
-    >>> generator('/docs/*')({'*': ('some', 'path')})
+    >>> generator('/docs/*')({'': ('some', 'path')})
     '/docs/some/path'
 
-    >>> generator('/docs/*/:name')({'*': ('some',), 'name': 'name'})
+    >>> generator('/docs/*/:name')({'': ('some',), 'name': 'name'})
     '/docs/some/name'
     """
 
@@ -150,7 +149,7 @@ def generator(path):
         if start > 0 and expression[start] != '/':
             expression = expression[:start + 1] + '/' + expression[start + 1:]
 
-        name = star.group('name') or '*'
+        name = star.group('name') or ''
         expression = re_stararg.sub('%%(%s)s' % name, expression)
     else:
         name = None
@@ -205,7 +204,7 @@ class Router(object):
         for route in self._routes:
             m = route.match(path)
             if m is not None:
-                yield Match(route, m.pop('*', None), m)
+                yield Match(route, m)
 
     def connect(self, route):
         """Use this method to add routes."""
