@@ -13,8 +13,8 @@ class ApplicationCase(unittest.TestCase):
         from otto.tests.utils import get_response
         app = Application()
         import webob.exc
-        @app.route('/')
+        @app.connect('/')
         def controller(request):
-            raise webob.exc.HTTPForbidden("Forbidden.")
+            raise webob.exc.HTTPForbidden("No access.").exception
         response = get_response(app, '/')
         self.assertTrue('403 Forbidden' in "".join(response))
